@@ -1,6 +1,7 @@
 from .swml_instructions import Answer, Hangup, Prompt, Play, Record, RecordCall, StopRecordCall, JoinRoom, Denoise, \
     StopDenoise, ReceiveFax, SendFax, SipRefer, Connect, Tap, StopTap, SendDigits, SendSMS, AI, Transfer, Execute, \
-    Return, Request, Switch, Cond, Set, Unset, Goto
+    Return, Request, Switch, Cond, Set, Unset, Goto, DataMap, Action, Say, Stop, ToggleFunctions, BackToBackFunctions, \
+    SetMetaData, PlaybackBG, StopPlaybackBG, UserInput
 
 from .swml_response import Section, SWMLResponse
 
