@@ -7,7 +7,7 @@ class TestSWMLSendDigits(unittest.TestCase):
 
     def test_send_digits_method(self):
         main_section = self.response.add_section('main')
-        main_section.send_digits("012345")
+        main_section.send_digits(digits="012345")
         expected_swml = '{"sections": {"main": [{"send_digits": {"digits": "012345"}}]}}'
         self.assertEqual(self.response.generate_swml(), expected_swml)
 
